@@ -25,7 +25,7 @@
 #include "config.h"
 #include "gtlsinputstream.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 struct _GTlsInputStream
 {
@@ -36,9 +36,9 @@ struct _GTlsInputStream
 
 static void g_tls_input_stream_pollable_iface_init (GPollableInputStreamInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (GTlsInputStream, g_tls_input_stream, G_TYPE_INPUT_STREAM,
-                         G_IMPLEMENT_INTERFACE (G_TYPE_POLLABLE_INPUT_STREAM, g_tls_input_stream_pollable_iface_init)
-                         )
+G_DEFINE_FINAL_TYPE_WITH_CODE (GTlsInputStream, g_tls_input_stream, G_TYPE_INPUT_STREAM,
+                               G_IMPLEMENT_INTERFACE (G_TYPE_POLLABLE_INPUT_STREAM, g_tls_input_stream_pollable_iface_init)
+                              )
 
 static void
 g_tls_input_stream_dispose (GObject *object)
@@ -115,7 +115,7 @@ g_tls_input_stream_pollable_create_source (GPollableInputStream *pollable,
   if (!conn)
     {
       ret = g_idle_source_new ();
-      g_source_set_name (ret, "[glib-networking] g_tls_input_stream_pollable_create_source dummy source");
+      g_source_set_static_name (ret, "[glib-networking] g_tls_input_stream_pollable_create_source dummy source");
       return ret;
     }
 
