@@ -38,7 +38,7 @@ struct _MockInteraction
   GError *static_error;
 };
 
-G_DEFINE_TYPE (MockInteraction, mock_interaction, G_TYPE_TLS_INTERACTION);
+G_DEFINE_FINAL_TYPE (MockInteraction, mock_interaction, G_TYPE_TLS_INTERACTION);
 
 static void
 mock_interaction_ask_password_async (GTlsInteraction    *interaction,
@@ -51,6 +51,8 @@ mock_interaction_ask_password_async (GTlsInteraction    *interaction,
   GTask *task;
 
   task = g_task_new (interaction, cancellable, callback, user_data);
+  g_task_set_source_tag (task, mock_interaction_ask_password_async);
+  g_task_set_name (task, "[glib-networking] mock_interaction_ask_password_async");
 
   if (self->static_error)
     g_task_return_error (task, g_error_copy (self->static_error));
@@ -67,6 +69,8 @@ mock_interaction_ask_password_finish (GTlsInteraction    *interaction,
 {
   g_return_val_if_fail (g_task_is_valid (result, interaction),
                         G_TLS_INTERACTION_UNHANDLED);
+  g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == mock_interaction_ask_password_async,
+                        G_TLS_INTERACTION_UNHANDLED);
 
   if (g_task_had_error (G_TASK (result)))
     {
@@ -112,6 +116,8 @@ mock_interaction_request_certificate_async (GTlsInteraction            *interact
   GTask *task;
 
   task = g_task_new (interaction, cancellable, callback, user_data);
+  g_task_set_source_tag (task, mock_interaction_request_certificate_async);
+  g_task_set_name (task, "[glib-networking] mock_interaction_request_certificate_async");
 
   if (self->static_error)
     g_task_return_error (task, g_error_copy (self->static_error));
@@ -130,6 +136,8 @@ mock_interaction_request_certificate_finish (GTlsInteraction    *interaction,
 {
   g_return_val_if_fail (g_task_is_valid (result, interaction),
                         G_TLS_INTERACTION_UNHANDLED);
+  g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == mock_interaction_request_certificate_async,
+                        G_TLS_INTERACTION_UNHANDLED);
 
   if (!g_task_propagate_boolean (G_TASK (result), error))
     return G_TLS_INTERACTION_FAILED;
